@@ -142,6 +142,7 @@ struct agent_info_t {
   uint32_t pkt_processor_ucode_ver;
   uint32_t sdma_ucode_ver;
   hsa_amd_iommu_version_t iommu_support;
+  uint8_t memory_properties[8];
 };
 
 // This structure holds memory pool information acquired through hsa info
@@ -188,6 +189,8 @@ static const uint32_t kLabelFieldSize = 25;
 static const uint32_t kValueFieldSize = 35;
 static const uint32_t kIndentSize = 2;
 
+static bool wsl_env = false;
+
 enum rocmi_int_format {
   ROCMI_INT_FORMAT_DEC = 1,
   ROCMI_INT_FORMAT_HEX = 2,
@@ -223,6 +226,16 @@ std::string int_to_string(uint32_t i,
   return sd.str();
 }
 
+static void DetectWSLEnvironment() {
+  const char *filePath = "/dev/dxg";
+  FILE *file = fopen(filePath, "r");
+  if (file) {
+    printf("WSL environment detected.\n");
+    fclose(file);
+    wsl_env = true;
+  }
+}
+
 static void printLabelInt(char const *l, int d, uint32_t indent_lvl = 0) {
   std::string ind(kIndentSize * indent_lvl, ' ');
 
@@ -293,6 +306,7 @@ static hsa_status_t AcquireSystemInfo(system_info_t *sys_info) {
   // Get mwaitx mode
   err = hsa_system_get_info(HSA_AMD_SYSTEM_INFO_MWAITX_ENABLED,
                                                      &sys_info->mwaitx_enabled);
+  RET_IF_HSA_ERR(err);
   // Get DMABuf support
   err = hsa_system_get_info(HSA_AMD_SYSTEM_INFO_DMABUF_SUPPORTED,
                                                      &sys_info->dmabuf_support);
@@ -491,6 +505,12 @@ AcquireAgentInfo(hsa_agent_t agent, agent_info_t *agent_i) {
                            &agent_i->coherent_host_access);
   RET_IF_HSA_ERR(err);
 
+  // Get memory properties
+  err = hsa_agent_get_info(agent,
+                           (hsa_agent_info_t) HSA_AMD_AGENT_INFO_MEMORY_PROPERTIES,
+                           agent_i->memory_properties);
+  RET_IF_HSA_ERR(err);
+
   // Check if the agent is kernel agent
   if (agent_i->agent_feature & HSA_AGENT_FEATURE_KERNEL_DISPATCH) {
     // Get flaf of fast_f16 operation
@@ -551,7 +571,8 @@ AcquireAgentInfo(hsa_agent_t agent, agent_info_t *agent_i) {
 
 static void DisplayAgentInfo(agent_info_t *agent_i) {
   printLabelStr("Name:", agent_i->name, 1);
-  printLabelStr("Uuid:", agent_i->uuid, 1);
+  if (!wsl_env || HSA_DEVICE_TYPE_CPU == agent_i->device_type)
+    printLabelStr("Uuid:", agent_i->uuid, 1);
   printLabelStr("Marketing Name:", agent_i->device_mkt_name, 1);
   printLabelStr("Vendor Name:", agent_i->vendor_name, 1);
 
@@ -628,20 +649,29 @@ static void DisplayAgentInfo(agent_info_t *agent_i) {
   }
 
   printLabelStr("Chip ID:", int_to_string(agent_i->chip_id), 1);
-  printLabelStr("ASIC Revision:", int_to_string(agent_i->asic_revision), 1);
+  if (!wsl_env)
+    printLabelStr("ASIC Revision:", int_to_string(agent_i->asic_revision), 1);
   printLabelStr("Cacheline Size:", int_to_string(agent_i->cacheline_size), 1);
-  printLabelInt("Max Clock Freq. (MHz):", agent_i->max_clock_freq, 1);
-  printLabelInt("BDFID:", agent_i->bdf_id, 1);
+  if (!wsl_env || HSA_DEVICE_TYPE_GPU == agent_i->device_type)
+    printLabelInt("Max Clock Freq. (MHz):", agent_i->max_clock_freq, 1);
+  if (!wsl_env)
+    printLabelInt("BDFID:", agent_i->bdf_id, 1);
   printLabelInt("Internal Node ID:", agent_i->internal_node_id, 1);
   printLabelInt("Compute Unit:", agent_i->compute_unit, 1);
   printLabelInt("SIMDs per CU:", agent_i->simds_per_cu, 1);
   printLabelInt("Shader Engines:", agent_i->shader_engs, 1);
   printLabelInt("Shader Arrs. per Eng.:", agent_i->shader_arrs_per_sh_eng, 1);
-  printLabelInt("WatchPts on Addr. Ranges:", agent_i->max_addr_watch_pts, 1);
+  if (!wsl_env)
+    printLabelInt("WatchPts on Addr. Ranges:", agent_i->max_addr_watch_pts, 1);
 
   if (agent_i->device_type == HSA_DEVICE_TYPE_GPU)
     printLabelStr("Coherent Host Access:", agent_i->coherent_host_access ? "TRUE":"FALSE", 1);
 
+  printLabel("Memory Properties:", false, 1);
+  if (hsa_flag_isset64(agent_i->memory_properties, HSA_AMD_MEMORY_PROPERTY_AGENT_IS_APU))
+    printf("%s", "APU");
+  printf("\n");
+
   printLabel("Features:", false, 1);
   if (agent_i->agent_feature & HSA_AGENT_FEATURE_KERNEL_DISPATCH) {
     printf("%s", "KERNEL_DISPATCH ");
@@ -1243,7 +1273,9 @@ int CheckInitialState(void) {
 int main(int argc, char* argv[]) {
   hsa_status_t err;
 
-  if (CheckInitialState()) {
+  DetectWSLEnvironment();
+
+  if (!wsl_env && CheckInitialState()) {
     return 1;
   }
   err = hsa_init();
